=======
Credits
=======

Original Creator
----------------

* Rodrigo Caballero <rodrigo.caballero@misu.su.se>

Development Lead
----------------

* Joy Monteiro <joy.monteiro@misu.su.se>

Contributors
------------

* Jeremy McGibbon <mcgibbon@uw.edu>
* Raymond Pierrehumbert <raymond.pierrehumbert@physics.ox.ac.uk>
* Dargan Frierson <dargan@atmos.washington.edu>
* Jonathan Mitchell <jonmitch@ucla.edu>
